summaryrefslogtreecommitdiffstats
path: root/src/Generating/Prefab.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Generating/Prefab.h')
-rw-r--r--src/Generating/Prefab.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Generating/Prefab.h b/src/Generating/Prefab.h
index 3733166ab..ec95c909b 100644
--- a/src/Generating/Prefab.h
+++ b/src/Generating/Prefab.h
@@ -40,8 +40,8 @@ public:
cPrefab(const sDef & a_Def);
- /** Draws the prefab into the specified block area, according to the placement stored in the PlacedPiece. */
- void Draw(cBlockArea & a_Dest, const cPlacedPiece * a_Placement);
+ /** Draws the prefab into the specified chunk, according to the placement stored in the PlacedPiece. */
+ void Draw(cChunkDesc & a_Dest, const cPlacedPiece * a_Placement) const;
/** Returns true if the prefab has any connector of the specified type. */
bool HasConnectorType(int a_ConnectorType) const;